
# /****************************************************************************
# *
# *    (C) Copyright 1989-2015 Trend Micro, Inc.
# *    All Rights Reserved.
# *
# *    This program is an unpublished copyrighted work which is proprietary
# *    to Trend Micro, Inc. and contains confidential information that is not
# *    to be reproduced or disclosed to any other person or entity without
# *    prior written consent from Trend Micro, Inc. in each and every instance.
# *
# *    WARNING:  Unauthorized reproduction of this program as well as
# *    unauthorized preparation of derivative works based upon the
# *    program or distribution of copies by sale, rental, lease or
# *    lending are violations of federal copyright laws and state trade
# *    secret laws, punishable by civil and criminal penalties.
# *
# * ---------------------------------------------------------------------------
# * Title: critical patch/hotfix install script
# * Project: SPLX 3.0
# * Revision: 
# * Author: 
# * Date: 
# * Description: 
# * Log: 
# *
# ***************************************************************************** 

echo "Check system ......"

is_32bit=-1
uname_i=`uname -m`
arch=""
platform=""
if [ "${uname_i}" = "i686" -o "${uname_i}" = "i386" -o "${uname_i}" = "i586" ]; then
    is_32bit=1
    arch="i686"
else
    is_32bit=0
    arch="x86_64"
fi

key_bin="/sbin/yast"
is_suse=1

if [ -f ${key_bin} ]; then
    is_suse=1
    platform="SuSE"
else
    is_suse=0
fi

is_splx_64=0
suse_release="/etc/SuSE-release"
if [ $is_suse -eq 1 ]; then
	query_is_suse12=`cat $suse_release | grep SUSE`
	ret_suse12="$?"
	if [ $ret_suse12 -eq 0 ]; then
		suse12_release=$(awk '(NR > 0) && ($5 == 12) { print $5 }' $suse_release)
		if [ $suse12_release ]; then
			is_splx_64=1
			platform="ALL"
		fi
	fi
fi

if [ -f /etc/os-release ] ; then
	grep -e "SUSE Linux Enterprise Server" -e "SUSE Linux Enterprise Desktop" /etc/os-release > /dev/null 2>&1
	if [ $? = 0 ] ; then
		is_splx_64=1
		platform="ALL"
	fi
fi

is_centOS6=0
is_platformRH6=0
rhel_release="/etc/redhat-release"
if [ $is_suse -ne 1 -a $is_splx_64 -ne 1 ]; then
    query_is_centOS=`cat $rhel_release | grep CentOS`
    ret_centOS="$?"
    if [ $ret_centOS -eq 0 ]; then
	centos_release=$(awk '(NR > 0) && ($4 >= 7) { print $4 }' $rhel_release)
	centos_release_2=$(awk '(NR > 0) && ($3 >= 7) { print $3 }' $rhel_release)
	if [ $centos_release ] || [ $centos_release_2 ] ; then
            is_splx_64=1
            platform="ALL"
	fi
	if [ $is_splx_64 -eq 0 ]; then
	    centos_release=$(awk '(NR > 0) && ($4 >= 6) && ($4 < 7) { print $4 }' $rhel_release)
	    centos_release_2=$(awk '(NR > 0) && ($3 >= 6) && ($3 < 7) { print $3 }' $rhel_release)
	    if [ $centos_release ] || [ $centos_release_2 ] ; then
		is_centOS6=1
		platform="RedHat6"
		is_platformRH6=1
	    fi
        fi
    fi
fi

if [ $is_suse -ne 1 -a $is_centOS6 -ne 1 -a $is_splx_64 -ne 1 ]; then
	release=$(awk '(NR > 0) && ($7 >= 7) { print $7 }' $rhel_release)
	if [ $release ]; then
        platform="ALL"
		is_splx_64=1
    fi
	if [ $is_splx_64 -eq 0 ]; then
		release=$(awk '(NR > 0) && ($7 >= 6) && ($7 < 7) { print $7 }' $rhel_release)
		if [ $release ]; then
			platform="RedHat6"
			is_platformRH6=1
		else
			platform="RedHat"
		fi
    fi
fi

echo "Starting to install package. Please wait."

# check if this script is run by root
if [ $UID -ne 0 ] ; then
    echo "You must be logged in as root to run this script."
    exit 1
fi

# check if initial SProtectLinux is installed
query_splx=`rpm -q SProtectLinux-3.0`
is_splx_existed=$?

if [ $is_splx_existed -ne 0 ] ; then
    echo "Please install ServerProtect for Linux 3.0 before installing this package."
    exit 1
else
    echo "The current installation of ServerProtect on your system is $query_splx."
fi

query_splx_p8=`rpm -q splx-3.0-sp1-patch8`
is_splx_p8_existed=$?
if [ $is_splx_p8_existed -ne 0 ] ; then
    echo "Please install SPLX 3.0 Patch8 for sp1 before installing this package."
    exit 1
fi

BuildNumber=1576
Postfix=cp

F_ini_set() {
    INI_F="$1"
    INI_SECTION="$2"
    INI_KEY="$3"
    INI_VALUE="$4"
    TMP_F=/tmp/temp$$

    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
    return 1
    fi

    RANGE_START="/\[${INI_SECTION}\]/"
    RANGE_END="/\\[.*\]/"

    MY_SEDCMD="${RANGE_START},${RANGE_END}s?^[ \t]*${INI_KEY}=.*?${INI_KEY}=${INI_VALUE}?"
    sed -e "${MY_SEDCMD}" ${INI_F} > ${TMP_F}
    cp -f ${TMP_F} ${INI_F}
    rm -f ${TMP_F}
}

F_ini_get()
{
    INI_F="$1"
    INI_SECTION="$2"
    INI_KEY="$3"
    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
        return 1
    fi

    RANGE_START="/^\[${INI_SECTION}\]/"
    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
        return 1
    fi

    RANGE_START="/^\[${INI_SECTION}\]/"
    RANGE_END="/^\[.*\]/"

    MY_SEDCMD_1="${RANGE_START},${RANGE_END}p"
    MY_SEDCMD_2="/^[\t ]*${INI_KEY}=/p"

    _R=`sed -n -e "${MY_SEDCMD_1}" ${INI_F} | sed -n -e "${MY_SEDCMD_2}" | awk -F= '{ printf $2 }'`
    printf "%s" "$_R"
    if [ -z "$_R" ] ; then
        return 1
    else
        return 0
    fi
}


CreatePatchIni()
{
File="/opt/TrendMicro/SProtectLinux/Patch.ini"
	
echo "[General]">>$File
echo "UpdateTime=">>$File
echo "">>$File
echo "[PreviousVersion]">>$File
echo "RpmVersion=">>$File
echo "ProtectVersion=3.0">>$File
echo "ServicePack=1">>$File
echo "PatchNumber=8">>$File
BuildNumber=1576
echo "">>$File
echo "[CurrentVersion]">>$File
echo "RpmVersion=">>$File
echo "ProductVersion=3.0">>$File
echo "ServicePack=1">>$File
echo "PatchNumber=">>$File
BuildNumber=1576
}

UpdatePatchIni()
{
#Get PreSPNumber
PreSPNumber=$(rpm -qa | grep splx | awk -F- '{print $3}' | cut -c 3-)
if [ -z "${PreSPNumber}" ]; then
   PreSPNumber=0
fi

#Get PrePatchNumber
PrePatchNumber=$(rpm -qa | grep splx | awk -F- '{print $4}' | cut -c 6-)
if [ -z "${PrePatchNumber}" ]; then
   PrePatchNumber=0
fi

#Get PreBuildNumber
BuildNumber=1576
if [ -z "${PreBuildNumber}" ]; then
BuildNumber=1576
fi

#Get PreRpmVersion
PreRpmVersion=`rpm -qa | grep splx`
if [ -z "${PreRpmVersion}" ]; then
   PreRpmVersion=`rpm -qa | grep SProtectLinux`
fi

#if Patch.ini is exist, get PreviousVersion from Patch.ini|CurrentVersion
File="/opt/TrendMicro/SProtectLinux/Patch.ini"
if [ -f $File ]; then
    #backup 
    cp -f $File /opt/TrendMicro/SProtectLinux/Patch.ini.bak
    PreRpmVer=`F_ini_get $File "CurrentVersion" "RpmVersion"`
    PrePatchNo=`F_ini_get $File "CurrentVersion" "PatchNumber"`
    PreBuildNo=`F_ini_get $File "CurrentVersion" "BuildNumber"`
    PreSPNo=`F_ini_get $File "CurrentVersion" "ServicePack"`
else
    #create new Patch.ini
    CreatePatchIni
    PreRpmVer=$PreRpmVersion
    PrePatchNo=$PrePatchNumber
    PreBuildNo=$PreBuildNumber
    PreSPNo=$PreSPNumber
fi

Date=`date`

F_ini_set $File "General" "UpdateTime" "$Date"
F_ini_set $File "PreviousVersion" "RpmVersion" "$PreRpmVer"
F_ini_set $File "PreviousVersion" "PatchNumber" "$PrePatchNo"
F_ini_set $File "PreviousVersion" "BuildNumber" "$PreBuildNo"
F_ini_set $File "PreviousVersion" "ServicePack" "$PreSPNo"

#the RpmVersion/ServicePack/PatchNumber of CurrentVersion should be same with PreviousVersion
F_ini_set $File "CurrentVersion" "RpmVersion" "$query_splx_p8"
F_ini_set $File "CurrentVersion" "ServicePack" "$PreSPNo"
F_ini_set $File "CurrentVersion" "PatchNumber" "$PrePatchNumber"
F_ini_set $File "CurrentVersion" "BuildNumber" "$BuildNumber"
}

File="/opt/TrendMicro/SProtectLinux/Patch.ini"
if [ -f $File ]; then
    BuildNo=`F_ini_get $File "CurrentVersion" "BuildNumber"`
    if [ "${BuildNo}" -eq "${BuildNumber}" ]; then
	echo "Package has been installed. Install process exits."
	exit 1
    fi
fi

# Stop SPLX   
echo "Stopping splx ......"
/etc/init.d/splx stop

#---------------------
bak_path=/opt/TrendMicro/SProtectLinux/backup/$Postfix$BuildNumber

if [ -d $bak_path ]; then
    rm -rf $bak_path/*
else
    mkdir -p $bak_path
fi   

if [ -f /opt/TrendMicro/SProtectLinux/tmsplx.xml ] ; then
    cp -f /opt/TrendMicro/SProtectLinux/tmsplx.xml $bak_path
fi

DefaultDirToMoveWhiteList="/opt/TrendMicro/SProtectLinux/SPLX.Quarantine"
DefaultDirToSaveWhiteList="/opt/TrendMicro/SProtectLinux/SPLX.Backup"

preDirToMoveValue=$(grep DirToMove /opt/TrendMicro/SProtectLinux/tmsplx.xml | grep -v '<--'  | awk -F= '{print $NF}' | awk -F\" '{print $2}')
preDirToSaveValue=$(grep DirToSave /opt/TrendMicro/SProtectLinux/tmsplx.xml | grep -v '<--'  | awk -F= '{print $NF}' | awk -F\" '{print $2}')

DirToSaveStr=$(grep DirToSave /opt/TrendMicro/SProtectLinux/tmsplx.xml | grep -v '<--')

if [ "${DefaultDirToMoveWhiteList}" != "${preDirToMoveValue}" ]; then
	DefaultDirToMoveWhiteList="${DefaultDirToMoveWhiteList}:$preDirToMoveValue"
fi

if [ "${DefaultDirToSaveWhiteList}" != "${preDirToSaveValue}" ]; then
	DefaultDirToSaveWhiteList="${DefaultDirToSaveWhiteList}:$preDirToSaveValue"
fi

DirToMoveWhiteList="   <P Name=\"MoveToWhiteList\" Value=\"$DefaultDirToMoveWhiteList\"/>"
DirToSaveWhiteList="   <P Name=\"SaveToWhiteList\" Value=\"$DefaultDirToSaveWhiteList\"/>"

grep "SaveToWhiteList" /opt/TrendMicro/SProtectLinux/tmsplx.xml > /dev/null

if [ $? -ne 0 ]; then
	sed -i "/DirToSave/a\ $DirToMoveWhiteList\n $DirToSaveWhiteList" /opt/TrendMicro/SProtectLinux/tmsplx.xml > /dev/null
fi

DefaultSource="https://splx3-p.activeupdate.trendmicro.com/activeupdate"
SourceValue=$(grep 'Name="Source"' /opt/TrendMicro/SProtectLinux/tmsplx.xml | grep -v '<--'  | awk -F= '{print $NF}' | awk -F\" '{print $2}')
DefaultSourceValue=$(grep 'Name="DefaultSource"' /opt/TrendMicro/SProtectLinux/tmsplx.xml | grep -v '<--'  | awk -F= '{print $NF}' | awk -F\" '{print $2}' | grep 'TVCSDownload')

if [ "${DefaultSourceValue}" == "" ]; then
	sed -i "/DefaultSource/c\\    <P Name=\"DefaultSource\" Value=\"${DefaultSource}\"/>" /opt/TrendMicro/SProtectLinux/tmsplx.xml > /dev/null
fi

if [ "${SourceValue}" == "" -a "${DefaultSourceValue}" == "" ]; then
	sed -i "/DigSig/c\\    <P Name=\"DigSig\" Value=\"1\"/>" /opt/TrendMicro/SProtectLinux/tmsplx.xml > /dev/null
	sed -i "/SrvAuth/c\\    <P Name=\"SrvAuth\" Value=\"1\"/>" /opt/TrendMicro/SProtectLinux/tmsplx.xml > /dev/null
fi

#check splx.service
is_systemd_exist=0

if [ $is_splx_64 -eq 1 ] ; then 
	check_results=`systemctl list-unit-files|grep splx.service`
	if [[ $check_results =~ "splx.service" ]] ; then
		is_systemd_exist=1
	fi
fi


#Copy files starts


#Copy files ends

#start splx service at boot(splx_64 + no splx.service)
if [ $is_splx_64 -eq 1 -a $is_systemd_exist -eq 0 ] ; then 
	systemctl enable splx.service >/dev/null 2>&1
fi

#if any, delete the old backup files
#find /opt/TrendMicro/SProtectLinux -name "*.bak.cp1519"|xargs rm -rf

# Modify BIF interval
if [ -f /etc/init.d/splxcore ]; then
    sed -i "s/$BIF_schedule_command=\"\* \* \* \* 0/$BIF_schedule_command=\"30 2 \* \* 0/g" /etc/init.d/splxcore > /dev/null
fi

# Modify MenuVersion number
if [ $is_splx_64 -eq 1 ]; then
	if [ -f /opt/TrendMicro/SProtectLinux/Product.ini ]; then
		sed -i "s/MenuVersion=3\.3/MenuVersion=3\.4/g" /opt/TrendMicro/SProtectLinux/Product.ini > /dev/null
	fi
	if [ -f /opt/TrendMicro/SProtectLinux/Product.ini.template ]; then
		sed -i "s/MenuVersion=3\.3/MenuVersion=3\.4/g" /opt/TrendMicro/SProtectLinux/Product.ini.template > /dev/null
	fi
else
	if [ -f /opt/TrendMicro/SProtectLinux/Product.ini ]; then
		sed -i "s/MenuVersion=3\.1/MenuVersion=3\.2/g" /opt/TrendMicro/SProtectLinux/Product.ini > /dev/null
	fi
	if [ -f /opt/TrendMicro/SProtectLinux/Product.ini.template ]; then
		sed -i "s/MenuVersion=3\.1/MenuVersion=3\.2/g" /opt/TrendMicro/SProtectLinux/Product.ini.template > /dev/null
	fi
fi

#added in cp 1519
UpdatePatchIni

#delete java applet files
find /opt/TrendMicro/SProtectLinux/ -name "*.jar"|xargs rm -rf
find /opt/TrendMicro/SProtectLinux/ -name "*.class"|xargs rm -rf
find /opt/TrendMicro/SProtectLinux/ -name "javaclass" |xargs rm -rf

ldconfig
# Start SPLX
echo "Starting splx ......"
/etc/init.d/splx start
echo "Successfully install package."
